summaryrefslogtreecommitdiff
path: root/app/helpers/workhorse_helper.rb
diff options
context:
space:
mode:
Diffstat (limited to 'app/helpers/workhorse_helper.rb')
-rw-r--r--app/helpers/workhorse_helper.rb4
1 files changed, 3 insertions, 1 deletions
diff --git a/app/helpers/workhorse_helper.rb b/app/helpers/workhorse_helper.rb
index 2460c956bb6..f1ddc2e902e 100644
--- a/app/helpers/workhorse_helper.rb
+++ b/app/helpers/workhorse_helper.rb
@@ -35,9 +35,11 @@ module WorkhorseHelper
head :ok
end
# Send an entry from artifacts through Workhorse
def send_artifacts_entry(file, entry)
headers.store(*Gitlab::Workhorse.send_artifacts_entry(file, entry))
+ headers.store(*Gitlab::Workhorse.detect_content_type)
+
head :ok
end
@@ -35,9 +35,11 @@ module WorkhorseHelper
head :ok
end
- # Send an entry from artifacts through Workhorse
+ # Send an entry from artifacts through Workhorse and set safe content type
def send_artifacts_entry(file, entry)
headers.store(*Gitlab::Workhorse.send_artifacts_entry(file, entry))